@@ -21,6 +21,7 @@ Config.check_first()
 _ = Config._
 Notify.init(Config.APPNAME)
 from kuwo.log import logger
+from kuwo import Net
 from kuwo import Widgets
 from kuwo.Artists import Artists
 from kuwo.Lrc import Lrc
@@ -102,6 +103,10 @@ class App:
         self.shortcut = Shortcut(self.player)
         self.osdlrc.after_init()
 
+        # Cleanup temporary media files
+        Net.cleanup_temp_files(self.conf['song-dir'])
+        Net.cleanup_temp_files(self.conf['mv-dir'])
+
     def on_app_shutdown(self, app):
         Config.dump_conf(self.conf)
 
